@@ -1,4 +1,4 @@
-package Pcore::SMTP v0.5.0;
+package Pcore::SMTP v0.5.1;
 
 use Pcore -dist, -const, -class, -result;
 use Pcore::AE::Handle qw[:TLS_CTX];
@@ -611,6 +611,9 @@ Pcore::SMTP - non-blocking SMTP protocol implementation
         tls      => 1,
     } );
 
+    # send email with two attachmants
+    $message_body = [ [ 'filename1.ext', \$content1 ], [ 'filename2.ext', \$content2 ] ];
+
     $smtp->sendmail(
         from     => 'from@host',
         reply_to => 'from@host',
@@ -628,8 +631,6 @@ Pcore::SMTP - non-blocking SMTP protocol implementation
         }
     );
 
-    $message_body = [ [ 'filename1.ext', \$content1 ], [ 'filename2.ext', \$content2 ], ... ];
-
 =head1 DESCRIPTION
 
 AnyEvent based SMTP protocol implementation.
@@ -638,6 +639,55 @@ AnyEvent based SMTP protocol implementation.
 
 =head1 METHODS
 
+=head2 sendmail(%args)
+
+Where %args are:
+
+=over
+
+=item from
+
+from email address.
+
+=item reply_to
+
+reply to email address.
+
+=item to
+
+This argument can be either Scalar or ArrayRef[Scalar].
+
+=item cc
+
+This argument can be either Scalar or ArrayRef[Scalar].
+
+=item bcc
+
+This argument can be either Scalar or ArrayRef[Scalar].
+
+=item subject
+
+Email subject.
+
+=item body
+
+Email body. Can be Scalar|ScalarRef|ArrayRef[Scalar|ScalarRef|ArrayRef].
+
+If body is ArrayRef - email will be composed as multipart/mixed. Each part can be a C<$body> or C<\$body> or a C<[$headers, $body]>. If C<$headers> ia plain scalar - this will be a filename, and headers array will be generated. Or you can specify all required headers manually in ArrayRef.
+
+Examples:
+
+    $body = 'message body';
+
+    $body = \'message body';
+
+    $body = [ $part1, \$part2, [ \@headers, $content ] ];
+
+    # send email with two file attachmants
+    $body = [ 'message body', [ 'filename1.txt', \$content1 ], [ 'filename2.txt', \$content2 ] ];
+
+=back
+
 =head1 NOTES
 
 If you are using gmail and get error 534 "Please log in via your web browser", go to L<https://myaccount.google.com/lesssecureapps> and allow less secure apps.
